@@ -1,9 +1,10 @@
-from pyspark.shell import spark
+from pyspark.sql import SparkSession
 
 from encoder import Encoder
 
 
 def main(dataset_path: str = "./data/show_ratings.csv") -> None:
+    spark = SparkSession.builder.getOrCreate()
     df = Encoder.prepare_df(spark.read.csv(dataset_path, header=True))
 
     encoded_df = Encoder.encode(df)
